Arch Packaging Files
--------------------

The PKGBUILD in this directory is here for reference.

You can install [ansible-git][1] from the Arch User Repository (AUR), using the [AUR helper][2] of your choice.

With `yaourt`:

    yaourt -S ansible-git

With `pikaur`:

    pikaur -S ansible-git

You can also install the stable version of [ansible][3] as an AUR package.

  [1]: https://aur.archlinux.org/packages/ansible-git/
  [2]: https://wiki.archlinux.org/index.php/AUR_helpers
  [3]: https://aur.archlinux.org/packages/ansible/
